@@ -1,6 +1,6 @@
 package Acme::PrettyCure::Girl::CureBeauty;
 use utf8;
-use Any::Moose;
+use Moo;
 
 with qw/Acme::PrettyCure::Girl::Role Acme::PrettyCure::Girl::Role::Smile/;
 
@@ -11,8 +11,4 @@ sub challenge { 'しんしんと降りつもる清き心! キュアビューテ
 sub color { 27 }
 sub image_url { 'http://www.toei-anim.co.jp/tv/precure/images/character/c5_1.jpg' }
 
-
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
