@@ -1,7 +1,6 @@
 package Acme::PrettyCure::Girl::CureEcho;
 use utf8;
-use Any::Moose;
-use Time::Piece;
+use Moo;
 
 with 'Acme::PrettyCure::Girl::Role';
 
@@ -10,8 +9,4 @@ sub precure_name {'キュアエコー'}
 sub challenge { "想いよ届け! キュアエコー!" }
 sub image_url { '' }
 
-
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
