@@ -1,6 +1,6 @@
 package Acme::PrettyCure::Girl::CureMelody;
 use utf8;
-use Any::Moose;
+use Moo;
 
 with qw/Acme::PrettyCure::Girl::Role Acme::PrettyCure::Girl::Role::Suite/;
 
@@ -23,7 +23,4 @@ before 'transform' => sub {
     }
 };
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
