@@ -1,6 +1,6 @@
 package Acme::PrettyCure::Girl::CurePine;
 use utf8;
-use Any::Moose;
+use Moo;
 
 with qw/Acme::PrettyCure::Girl::Role Acme::PrettyCure::Girl::Role::Fresh/;
 
@@ -11,8 +11,4 @@ sub challenge { qw(イエローハートは祈りの印 とれたてフレッシ
 sub color { 214 }
 sub image_url { 'http://www.toei-anim.co.jp/tv/fresh_precure/character/img/main/curepain_l.jpg' }
 
-
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
